@@ -11,10 +11,10 @@ test_that("trapezoidarea is the area under curve using trapezoid rule", {
 
 
 test_that("invlogit computes logistic transform", {
-  expect_equal(invlogit(0), 0.5)
-  expect_equal(invlogit(-Inf), 0)
-  expect_equal(invlogit(Inf), 1)
-  expect_equal(round(invlogit(0.5),2), 0.62)
+  expect_equal(plogis(0), 0.5)
+  expect_equal(plogis(-Inf), 0)
+  expect_equal(plogis(Inf), 1)
+  expect_equal(round(plogis(0.5),2), 0.62)
 })
 
 
